@@ -111,7 +111,7 @@ $lang = array_merge($lang, array(
 	'MAX_AVATAR_SIZE'	=> 'أقصى الأبعاد للصور الشخصية',
 	'MAX_AVATAR_SIZE_EXPLAIN'	=> 'الارتفاع × العرض بالبكسل',
 	'MAX_FILESIZE'	=> 'أقصى حجم لملف الصورة الشخصية',
-	'MAX_FILESIZE_EXPLAIN'	=> 'للصور الشخصية التي سترفع على خادم المنتدى',
+	'MAX_FILESIZE_EXPLAIN'	=> 'للصور الشخصية التي سترفع على خادم المنتدى. إذا كانت القيمة 0، فإن حجم الملف سيكون محدودا فقط بإعدادات PHP لديك.',
 	'MIN_AVATAR_SIZE'	=> 'أدنى الأبعاد للصور الشخصية',
 	'MIN_AVATAR_SIZE_EXPLAIN'	=> 'الارتفاع × العرض بالبكسل',
 	'ACP_MESSAGE_SETTINGS_EXPLAIN'	=> 'هنا يمكنك وضع الإعدادت الافتراضية للرسائل الخاصة',
