@@ -92,7 +92,7 @@ $lang = array_merge($lang, array(
 	'ACP_GROUPS'	=> 'المجموعات',
 	'ACP_GROUPS_FORUM_PERMISSIONS'	=> 'صلاحيات المجموعات لكل منتدى',
 	'ACP_GROUPS_MANAGE'	=> 'إدارة المجموعات',
-	'ACP_GROUPS_MANAGEMENT'	=> 'إدارة المجموعة',
+	'ACP_GROUPS_MANAGEMENT'	=> 'إدارة المجموعات',
 	'ACP_GROUPS_PERMISSIONS'	=> 'صلاحيات المجموعات',
 	'ACP_ICONS'	=> 'أيقونات الموضوع',
 	'ACP_ICONS_SMILIES'	=> 'أيقونات/ابتسامات الموضوع',
@@ -151,7 +151,7 @@ $lang = array_merge($lang, array(
 	'ACP_THEMES'	=> 'الثيمات',
 	'ACP_UPDATE'	=> 'التحديث',
 	'ACP_USERS_FORUM_PERMISSIONS'	=> 'صلاحيات الأعضاء لكل منتدى',
-	'ACP_USERS_LOGS'	=> 'سجلات العضو',
+	'ACP_USERS_LOGS'	=> 'سجلات الأعضاء',
 	'ACP_USERS_PERMISSIONS'	=> 'صلاحيات الأعضاء',
 	'ACP_USER_ATTACH'	=> 'المرفقات',
 	'ACP_USER_AVATAR'	=> 'الصورة الشخصية',
@@ -329,7 +329,7 @@ $lang = array_merge($lang, array(
 	'INACTIVE_REASON_UNKNOWN'	=> 'غير معروف',
 	'INACTIVE_USERS'	=> 'أعضاء غير مفعلين',
 	'INACTIVE_USERS_EXPLAIN'	=> 'هذه قائمة بالأعضاء المسجلين لكن حساباتهم غير مفعلة. يمكنك تفعيلها أو حذفها أو تذكير هؤلاء الأعضاء (عن طريق إرسال بريد) إذا أردت',
-	'INACTIVE_USERS_EXPLAIN_INDEX'	=> 'هذه لائحة بآخر 10 أعضاء مسلجين لم يفعلوا عضوياتهم، اللائحة الكاملة يمكن الوصول إليها من القائمة المناسبة أو بالضغط على الرابط أدناه حيث يمكنك تفعيل هذه العضويات أو حذفها أو تذكير هؤلاء الأعضاء (عن طريق ارسال بريد) إذا أردت ذلك',
+	'INACTIVE_USERS_EXPLAIN_INDEX'	=> 'هذه لائحة بآخر 10 أعضاء مسلجين لم يفعلوا عضوياتهم. هذه العضويات غير مفعلة إما لأن تفعيل الحساب تم تشغيلها في إعدادات التسجيل وهذه العضويات لم يتم تفعيلها بعد، أو لأن هذه العضويات قد تم تعطيلها. اللائحة الكاملة يمكن الوصول إليها من القائمة المناسبة أو بالضغط على الرابط أدناه حيث يمكنك تفعيل هذه العضويات أو حذفها أو تذكير هؤلاء الأعضاء (عن طريق ارسال بريد) إذا أردت ذلك.',
 	'NO_INACTIVE_USERS'	=> 'لا يوجد أعضاء غير مفعلين',
 	'SORT_INACTIVE'	=> 'تاريخ الخمول',
 	'SORT_LAST_VISIT'	=> 'آخر زيارة',
