@@ -172,7 +172,7 @@ $lang = array_merge($lang, array(
 	'ROLE_FORUM_POLLS'		=> 'تصفح متوسط + الاستفتاءات',
 	'ROLE_FORUM_READONLY'		=> 'التصفح للقراءة فقط',
 	'ROLE_FORUM_STANDARD'		=> 'تصفح متوسط',
-	'ROLE_FORUM_NEW_MEMBER'		=> 'العضو المُسجل الجديد',
+	'ROLE_FORUM_NEW_MEMBER'		=> 'وصول العضو المُسجل الجديد',
 	'ROLE_MOD_FULL'				=> 'إشراف كامل',
 	'ROLE_MOD_QUEUE'			=> 'إشراف بسيط جدا',
 	'ROLE_MOD_SIMPLE'			=> 'إشراف بسيط',
@@ -182,7 +182,7 @@ $lang = array_merge($lang, array(
 	'ROLE_USER_NOAVATAR'		=> 'لا صورة شخصية',
 	'ROLE_USER_NOPM'			=> 'لا رسائل خاصة',
 	'ROLE_USER_STANDARD'		=> 'خصائص متوسطة',
-	'ROLE_USER_NEW_MEMBER'		=> 'العضو المُسجل الجديد',
+	'ROLE_USER_NEW_MEMBER'		=> 'مميزات العضو المُسجل الجديد',
 
 	
 	'ROLE_DESCRIPTION_ADMIN_FORUM'			=> 'يستطيع الوصول إلى إدارة المنتديات وإعدادت صلاحيات المنتديات',
