@@ -184,7 +184,7 @@ $lang = array_merge($lang, array(
 	'FORM_INVALID'	=> 'النموذج المقدم غير صحيح. حاول تقديمه مرة أخرى',
 	'FORUM'	=> 'ساحة',
 	'FORUMS'	=> 'ساحات',
-	'FORUMS_MARKED'	=> 'المنتديات المحددة عدّت مقروءة',
+	'FORUMS_MARKED'	=> 'عدّت المنتديات مقروءة.',
 	'FORUM_CAT'	=> 'تصنيف منتدى',
 	'FORUM_INDEX'	=> 'قائمة المنتديات',
 	'FORUM_LINK'	=> 'رابط المنتدى',
@@ -430,6 +430,7 @@ $lang = array_merge($lang, array(
 	'POST_TIME'	=> 'وقت الإرسال',
 	'POST_TOPIC'	=> 'إضافة موضوع جديد',
 	'POST_UNAPPROVED'	=> 'هذه المشاركة تنتظر الموافقة',
+	'POWERED_BY'			=> 'Powered by %s',
 	'PREVIEW'	=> 'استعراض',
 	'PREVIOUS'	=> 'السابق',
 	'PREVIOUS_STEP'	=> 'السابق',
@@ -438,6 +439,7 @@ $lang = array_merge($lang, array(
 	'PRIVATE_MESSAGES'	=> 'رسائل خاصة',
 	'PRIVATE_MESSAGING'	=> 'إرسال خاص',
 	'PROFILE'	=> 'لوحة التحكم',
+	'RANK'						=> 'الرتبة',
 	'READING_FORUM'	=> 'يشاهد المواضيع في %s',
 	'READING_GLOBAL_ANNOUNCE'	=> 'يقرأ اعلان عام',
 	'READING_LINK'	=> 'يتبع الرباط التالي %s',
