@@ -67,11 +67,11 @@ $help = array(
         1 => 'COPPA, أو قانون حماية خصوصية الأطفال على الويب هو قانون في الولايات المتحدة الأمريكية صدر في عام 1998 يطلب من المواقع التي تجمع معلومات من القاصرين تحت سن 13 أن تُكتَب وصاية أبوية, أو أشكال أخرى للوصاية القانونية بأن يسمحوا بجمع معلومات خاصة معرفة من القاصر تحت سن 13.إذا كنت غير متأكد إذا كان ينطبق عليك هذا القانون بوصفك شخصا فالرجاء الانتباه بأن الموقع لا يقدم أي نصائح قانونية ',
     ),
     array(
-        0    => 'لماذا لا يمكنني التسجيل ؟',
+        0    => 'لماذا لا يمكنني التسجيل؟',
         1    => 'من الممكن بأن مدير الموقع قد قام بحظر الآي بي الخاص بك أو حظر اسم المستخدم الذي استعملته للتسجيل. أو من الممكن أن يكون مدير الموقع قد قام بإيقاف عمليه التسجيل . اتصل بمدير الموقع للمساعدة ',
     ),
     array(
-        0    => 'ماذا يحدث إذا حذفت الملفات المؤقتة الخاصة بالمنتدى ؟',
+        0    => 'ماذا يحدث إذا حذفت الملفات المؤقتة الخاصة بالمنتدى؟',
         1    => 'حذف الملفات المؤقتة يحذف الملفات المؤقتة ( cookies ) التي أنشأها المنتدى والتي تجعلك مسجلاً للدخول وتلغي بعض المميزات المرتبطة بنظام الملفات المؤقتة ',
     ),
     array(
@@ -119,7 +119,7 @@ $help = array(
         1    => 'ما لم تكن مدير الموقع أو المشرف فلن تستطيع إلا تعديل مواضيعك الخاصة أو إلغاءها. تستطيع تعديل موضوع (أحيانا لوقت قصير بعد كتابته) بالضغط على زر  <i>تعديل</i> عند نفس الموضوع.  إذا رُدّ على الموضوع سوف تجد قليلاً من الجمل أسفل الموضوع, هذا يظهر عدد مرات تعديلك للموضوع. سوف تظهر هذه الجملة إذا قام أحد بالرد على الموضوع, ولن تظهر إذا قام المشرف أو المدير بتعديل الموضوع (عليهم ترك رسالة يذكرون في سبب تعديلهم وما هو التعديل). للعلم لا يستطيع المستخدمون العاديون إلغاء الموضوع إذا ردّ عليه أحد',
     ),
     array(
-        0    => 'كيف أرفق توقيع مع موضوعي ؟',
+        0    => 'كيف أرفق توقيع مع موضوعي؟',
         1    => 'لإضافة توقيع للموضوع عليك تكوين توقيع أولاً, تستطيع فعل ذلك عن طريق ملفك الشخصي. فور تكوين التوقيع تستطيع الضغط على <i>أضف توقيع</i> في شاشة كتابة الموضوع. تستطيع إضافة التوقيع آليا في كتاباتك كلها بتشغيل الاختيار الخاص بذلك في ملفك الشخصي (تستطيع كذلك توقيف إضافة التوقيع لكل رسالة على حده بإزالة الاختيار الخاص بذلك في شاشة الموضوع)',
     ),
     array(
@@ -127,39 +127,39 @@ $help = array(
         1    => 'تستطيع تكوين استفتاء بكل سهولة, عند تكوين موضوع جديد (أو تعديل النشر الأول للموضوع, إن كانت لك تلك الصلاحية) سوف ترى نموذج <i>أضف استفتاء</i> أسفل شاشة إضافة الموضوع (إن لم ترَ هذه الإضافة قد لا يكون لك الصلاحية لذلك). سوف ترى عنوان الاستفتاء واختيارين إضافيين (لإضافة اختيار أضف السؤال ثم اضغط على وصلة <i>أضف جواب</i>. تستطيع أن تضع وقتا زمنيا للاستفتاء, صفر تعني الوقت مفتوح للاستفتاء. هناك حد أقصى لعدد الأجوبة للاستفتاء, وهو يحدد من المسؤول',
     ),
     array(
-        0    => 'كيف أستطيع تعديل تصويت ما أو إلغاءه ؟',
+        0    => 'كيف أستطيع تعديل تصويت ما أو إلغاءه؟',
         1    => 'كما هو الحال بالنسبة للمواضيع, الشخص الذي وضع الاستفتاء هو الوحيد الذي يستطيع تعديلها أو إلغائها , أو المشرف أو المسؤول. لتعديل استفتاء اضغط تعديل على أول إرسال للموضوع (وهي دائماً مرتبطة بالاستفتاء الذي تم وضعه). إن لم يجب أي شخص على الاستفتاء تستطيع تعديل وإلغاء الاستفتاء, لكن إن أُجيب عليه فالمشرف والمسؤول هما الأشخاص الوحيدون المسموح لهم بالتعديل والإلغاء. وهذا لمنع الأشخاص من تغيير الأسئلة والأجوبة وتزوير الاستفتاءات في وسط الفترة',
     ),
     array(
-        0    => 'لماذا لا أستطيع دخول الساحة ؟',
+        0    => 'لماذا لا أستطيع دخول الساحة؟',
         1    => 'بعض الساحات قد تكون محددة الصلاحية لمجموعة معينة أو مسجلين معينين للاطلاع أو القراءة أو إضافة موضوع. قد لا تكون من ضمن تلك المجموعة أو المسجلين. وحدهم المشرفون ومدير المنتدى يمكنهم إعطاؤك الصلاحية لذلك. عليك الاتصال بهم',
     ),
     array(
-        0    => 'لماذا لا يمكنني المشاركة في التصويت ؟',
+        0    => 'لماذا لا يمكنني المشاركة في التصويت؟',
         1    => 'فقط المسجلون في المنتدى يمكنهم المشاركة في التصويت إذا كنت مسجلاً للدخول ولا تستطيع المشاركة في التصويت فتأكد من عملية تسجيل دخولك أو اتصل بمدير الموقع',
     ),
     array(
-        0    => 'لماذا لا أستطيع إضافة المرفقات  ؟',
+        0    => 'لماذا لا أستطيع إضافة المرفقات؟',
         1    => 'لقد حدد مسؤول الموقع الحد الأقصى لحجم الملف ,امتداد الملف و نوع المرفقات في المنتدى . أو ربما تغيرت صلاحيتك من مسؤول الموقع , أو عدم استمرارية إرفاق الملفات في هذا المنتدى بالتحديد . قد تحصل على التوضيح لنص رسالة الخطأ عند محاولتك إرفاق الملف , إذا لم تظهر لك رسالة ما فعليك الاتصال بمسؤول الموقع',
     ),
     array(
-        0    => 'لماذا أتلقى تحذيرات ؟',
+        0    => 'لماذا أتلقى تحذيرات؟',
         1    => 'كل مدير منتدى لديه شروط و قوانين اشتراك خاصة. إذا قمت بتجاوز هذه الشروط و القوانين فيحذرونك. انتبه إلى أن القرار يعود إلى مدير المنتدى ولا علاقة لمجموعة phpBB بتلك القوانين أو الاشتراطات',
     ),
     array(
-        0    => 'كيف يمكنني إرسال التقرير عن مشاركة للمشرف ؟',
+        0    => 'كيف يمكنني إرسال التقرير عن مشاركة للمشرف؟',
         1    => 'إذا سمح مدير المنتدى بذلك ، اذهب إلى المشاركة المراد التقرير عنها وستجد أيقونة خاصة للتقرير عن الموضوع. اضغط على الأيقونة وقم بالخطوات لإتمام عملية التقرير',
     ),
     array(
-        0    => 'ما هي أيقونة حفظ الموضوع الموجودة في الموضوع ؟',
+        0    => 'ما هي أيقونة حفظ الموضوع الموجودة في الموضوع؟',
         1    => 'هي خاصية تسمح لك بحفظ الموضوع لإكماله في وقت لاحق حتى تتمكن من إضافته. لمعرفة المزيد اتجه إلى لوحة التحكم الشخصية و اتبع الروابط ',
     ),
     array(
-        0    => 'لماذا تحتاج مواضيعي للموافقة عليها ؟',
+        0    => 'لماذا تحتاج مواضيعي للموافقة عليها؟',
         1    => 'من الممكن أن يكون مدير المنتدى قد حدد في ساحة معينة الاطلاع على الموضوع قبل اعتماده أو أنك أصبحت عضواً في مجموعة يطلع مدير المنتدى على مشاركاتهم قبل نشرها. لمزيد من المعلومات اتصل بمدير المنتدى',
     ),
     array(
-        0    => 'كيف أنشر موضوع في المنتدى ؟',
+        0    => 'كيف أنشر موضوع في المنتدى؟',
         1    => 'بسهولة اضغط على الزر الخاص بموضوع المنتدى أو على نشر رد. قد تحتاج التسجيل لنشر موضوع, الإمكانيات المتاحة لك مذكورة في أسفل الصفحة (فجملة تستطيع نشر مواضيع جديدة, تستطيع المشاركة في التصويت, وغيرها)',
     ),
     array(
@@ -167,39 +167,39 @@ $help = array(
         1    => 'التنسيق وأنواع المواضيع',
     ),
     array(
-        0    => 'ما هو BBCode ؟',
+        0    => 'ما هو BBCode؟',
         1    => 'BBCode هو تطبيق خاص من  HTML, صلاحية استعمالك لها تحدد من المسؤول (تستطيع تعطيلها لكل موضوع تنشره على حدة). BBCode تستعمل نفس الطريقة في الكتابة التي يستعملها HTML, الرموز محاطة بأقواس مربعة بدلاً من &lt; and &gt; وتعطي تحكما أكثر في تنسيق النص. لمزيد من المعلومات عن BBCode انظر الدليل الخاص بها في شاشة كتابة الموضوع',
     ),
     array(
-        0    => 'هل أستطيع استعمال HTML ؟',
+        0    => 'هل أستطيع استعمال HTML؟',
         1    => 'هذا يعتمد على سماح المسؤول لك أيضاً, لهم مطلق الصلاحية بذلك. إن كان مسموحا لك لذلك فإن عدد الرموز المسموحة قليلة. وهذا  <i>صمام أمان</i> لمنع المسيئين من تخريب المنتدى أو التسبب بمشاكل أخرى. إن كانت HTML فعالة فإنك تستطيع تعطيلها لكل موضوع تنشره',
     ),
     array(
-        0    => 'ما هي الوجوه الضاحكة ؟',
-        1    => 'الوجوه الضاحكة أو التعبيرية هي صور صغيرة من الممكن استعمالها للتعبير عن المشاعر باستعمال حروف قليلة, مثلاً الرمزين :) تعني سعيد, :( تعني حزين. قائمة كاملة بالوجوه موجودة عند تقديم موضوع أو رد جديد ، حاول ألاّ تكثر من استعمال الوجوه, فقد يجعل هذا الموضوع غير قابل للقراءة مما يدعو المشرف إلى تعديل الموضوع أو حتى إزالته تماماً',
+        0    => 'ما هي الابتسامات؟',
+        1    => 'الابتسامات هي صور صغيرة من الممكن استعمالها للتعبير عن المشاعر باستعمال حروف قليلة, مثلاً الرمزين :) تعني سعيد, :( تعني حزين. قائمة كاملة بالوجوه موجودة عند تقديم موضوع أو رد جديد ، حاول ألاّ تكثر من استعمال الوجوه, فقد يجعل هذا الموضوع غير قابل للقراءة مما يدعو المشرف إلى تعديل الموضوع أو حتى إزالته تماماً',
     ),
     array(
         0    => 'هل أستطيع إرفاق صور؟',
         1    => 'نعم ، يمكن إرفاق صورة في الموضوع. في كل الأحوال إذا سمح مدير المنتدى خاصية المرفقات يمكنك إضافة صورة للمنتدى. وأيضاً يمكنك إضافتها من رابط صورة مرفوعة على موقع مثلاً http://www.example.com/my-picture.gif ولا يمكنك إضافة صورة محفوظة على جهاز الكمبيوتر الخاص بك أو صورة محفوظة على خادم محمي بكلمة مرور مثل hotmail أو Yahoo . لإضافة صورة يجب وضع الرابط الصحيح بين وسم BBCode الخاص بذلك [img]',
     ),
     array(
-        0    => 'ما هي الإعلانات العامة ؟',
+        0    => 'ما هي الإعلانات العامة؟',
         1    => 'الإعلانات العامة تحوي معلومات مهمة يتوجب الاطلاع عليها. وستظهر الإعلانات العامة أعلى الساحات جميعها وفي لوحة تحكم ملفك الشخصي أيضاً. إضافة موضوع كإعلان عام يعود إلى صلاحياتك الموضوعة من مدير المنتدى',
     ),
     array(
-        0    => 'ما هي الإعلانات ؟',
+        0    => 'ما هي الإعلانات؟',
         1    => 'قد تحتوي الإعلانات على معلومات مهمة لذا عليك قراءتها في أقرب وقت. تظهر الإعلانات في أعلى أي منتدى. إمكانية نشر الإعلان تعتمد على صلاحياتك, وهي تحدد من المسؤول',
     ),
     array(
-        0    => 'ما هي المواضيع المثبتة ؟',
+        0    => 'ما هي المواضيع المثبتة؟',
         1    => 'المواضيع المثبتة تظهر أسفل الإعلانات في المنتدى. وهي على درجة من الأهمية لذا عليك قراءتها. كما هو الحال بالنسبة للإعلانات فإن نشر المواضيع المثبتة تعتمد على الصلاحيات المسموح بها',
     ),
     array(
-        0    => 'ما هي المواضيع المقفلة ؟',
+        0    => 'ما هي المواضيع المقفلة؟',
         1    => 'المواضيع المقفلة تحدد من المشرف أو مسؤول المنتدى. لا تستطيع الرد على المواضيع المقفلة ولا على أي استفتاءات مرتبطة بها. قد تقفل المواضيع لأسباب عدة',
     ),
     array(
-        0    => 'ما هي أيقونة الموضوع ؟',
+        0    => 'ما هي أيقونة الموضوع؟',
         1    => 'أيقونة الموضوع هي صور ترفق بجانب عنوان الموضوع للتعبير عن محتواه. استخدام هذه الخاصية تعود لوضع مدير المنتدى لصلاحية استخدامها ',
     ),
     // This block will switch the FAQ-Questions to the second template column
@@ -212,35 +212,35 @@ $help = array(
         1    => 'مستوى المشتركين والمجموعات',
     ),
     array(
-        0    => 'من هم المسئولون ؟',
+        0    => 'من هم المسئولون؟',
         1    => 'المسؤولون لهم أعلى الصلاحيات بالنسبة لمواضيع وردود المنتديات. ولهم الحق في التحكم بالمنشورات كلها في المنتدى من صلاحيات أو منع مشتركين أو تكوين مجموعات أو تحديد مشرفين وغيرها من المهام. وأيضاً لهم حقوق المشرفين كاملة في المنتديات جميعها',
     ),
     array(
-        0    => 'من هم المشرفون ؟',
+        0    => 'من هم المشرفون؟',
         1    => 'المشرفون هم أفراد (أو مجموعة من الأفراد) ولهم وظيفة المتابعة اليومية للمنتدى. لهم صلاحية تعديل وإلغاء وقفل، وفتح, ونقل, وتقسيم المواضيع في المنتدى المشرفين عليه. بشكل عام المشرفون مسؤولون عن إبقاء الردود والمواضيع ضمن العنوان الرئيسي للمنتدى ومنعهم من نشر المواضيع المشينة',
     ),
     array(
-        0    => 'ما هي مجموعات المستخدمين ؟',
+        0    => 'ما هي مجموعات المستخدمين؟',
         1    => 'مجموعات المستخدمين هي طريقة لجمع عدد من المشتركين. يمكن للمشترك الواحد أن يكون في مجموعات عدة (وهذا يختلف عن الكثير من أنواع المنتديات الأخرى) ويمكن تحديد صلاحيات لكل مجموعة من هذه المجموعات. هذا يمكن من تحديد أكثر من مشرف للمنتدى, أو لإعطائهم الصلاحية لمنتديات خاصة',
     ),
     array(
-        0    => 'كيف أشارك في مجموعة مستخدمين ؟',
+        0    => 'كيف أشارك في مجموعة مستخدمين؟',
         1    => 'للمشاركة في مجموعات المستخدمين عليك الضغط على وصلة المجموعات في أعلى الصفحة (هذا يعتمد على التنسيق المستخدم), تستطيع رؤية المستخدمين جميعهم. ليست كل المجموعات  <i>مفتوحة</i>، بعضها مغلقة والبعض مختفية. إن كانت المجموعة مفتوحة وكنت تريد المشاركة يمكنك الضغط على الوصلة الخاصة بذلك. على مشرف المجموعة السماح لك بالمشاركة, قد تسأل عن سبب رغبتك في المشاركة. الرجاء عدم الإلحاح على مشرف المجموعة إن رفض طلبك للمشاركة, فإن لهم أسبابهم لذلك',
     ),
     array(
-        0    => 'كيف أصبح مشرفاً لمجموعة مستخدمين ؟',
+        0    => 'كيف أصبح مشرفاً لمجموعة مستخدمين؟',
         1    => 'تكون المجموعات لمصمم المنتدى أولاً, ويتحدد المشرفون في ذلك الوقت. إن كنت تريد تكوين مجموعة مستخدمين فإن أول اتصال سوف يكون بمسؤول المنتدى, حاول إرسال رسالة خاصة للمسؤول',
     ),
     array(
-        0    => 'لماذا تظهر بعض المجموعات بلون مختلف ؟',
+        0    => 'لماذا تظهر بعض المجموعات بلون مختلف؟',
         1    => 'من الممكن أن يكون مدير المنتدى خصص ألوان معينة للمجموعات ليميزهم عن غيرهم من الأعضاء الآخرين ',
     ),
     array(
-        0    => 'ما هي المجموعة الافتراضية ؟',
+        0    => 'ما هي المجموعة الافتراضية؟',
         1    => 'إذا كنت عضو في أكثر من مجموعة فمجموعتك الافتراضية هي التي يكون اسمك بنفس لونها ولك شعار المجموعة . قد يكون مدير المنتدى أعطى الصلاحية للأعضاء بتغير مجموعتهم الافتراضية من خلال لوحة التحكم الشخصية ',
     ),
     array(
-        0    => 'ما هي وصلة الطاقم الإداري ؟',
+        0    => 'ما هي وصلة الطاقم الإداري؟',
         1    => 'هذه الصفحة بها قائمة بفريق المنتدى وتتضمن مدير المنتدى و المشرفين مع المعلومات الخاصة بهم كلها ',
     ),
     array(
@@ -264,11 +264,11 @@ $help = array(
         1    => 'قائمة الأصدقاء والتجاهل',
     ),
     array(
-        0    => 'ما هي قائمة الأصدقاء و التجاهل ؟',
+        0    => 'ما هي قائمة الأصدقاء و التجاهل؟',
         1    => 'يمكنك استخدام القائمة لتنظيم أعضاء المنتدى الآخرين . الأعضاء المضافون في قائمة الأصدقاء سيدرجون في لوحة التحكم الشخصية وستتمكن من الوصول السريع إليهم لمعرفة حالة الاتصال أو إرسال رسالة خاصة . الأعضاء المضافون إلى قائمة التجاهل سيخفَونَ تلقائيا عنك ',
     ),
     array(
-        0    => 'كيف يمكن إضافة / إلغاء الأعضاء من قائمة الأصدقاء أو التجاهل ؟',
+        0    => 'كيف يمكن إضافة / إلغاء الأعضاء من قائمة الأصدقاء أو التجاهل؟',
         1    => 'يمكنك إضافة الأعضاء إلى قائمتك الخاصة بطريقتين . في عرض ملف العضو هناك وصلة لإضافة العضو إلى قائمة الأصدقاء أو قائمة التجاهل . بدلاً من ذلك من لوحة التحكم الشخصية الخاصة بك يمكنك مباشرة إضافة العضو إلى قائمة الأصدقاء أو التجاهل عن طريق إضافة اسم العضو ويمكنك إلغاء اسم العضو من نفس الصفحة ',
     ),
     array(
@@ -276,11 +276,11 @@ $help = array(
         1    => 'البحث في الأقسام',
     ),
     array(
-        0    => 'كيف يمكنني البحث في الأقسام ؟',
+        0    => 'كيف يمكنني البحث في الأقسام؟',
         1    => 'بإدخال كلمة البحث في حقل البحث الموجود في الصفحة الرئيسية أو صفحة عرض الساحة أو صفحة عرض الموضوع ويمكنك للبحث المتقدم الضغط على رابط البحث المتوفر أعلى الصفحات كلها ',
     ),
     array(
-        0    => 'لماذا بحثي لا يعطي نتائجا ؟',
+        0    => 'لماذا بحثي لا يعطي نتائجا؟',
         1    => 'من الممكن أن يكون بحثك مبهما و لا يتضمن الكلمات المفهرسة من  phpBB3 لذا ابحث مرة أخرى و كن أكثر تحديداً و استعمل الخيارات المتوفرة ضمن البحث المتقدم ',
     ),
     array(
@@ -288,11 +288,11 @@ $help = array(
         1    => 'بحثك قد أعطى الكثير من النتائج مما قد يسبب بضغط على الخادم. لذا استخدم البحث المتقدم و كن أكثر تحديداً بالبحث بشروط معينة و ساحات معينة ',
     ),
     array(
-        0    => 'كيف يمكن البحث عن عضو ؟',
+        0    => 'كيف يمكن البحث عن عضو؟',
         1    => 'اذهب إلى صفحة الأعضاء واضغط على البحث عن عضو واملأ الخيارات والحقول لإتمام عملية البحث ',
     ),
     array(
-        0    => 'كيف يمكن إيجاد المواضيع و المشاركات كلها الخاصة بي في المنتدى ؟',
+        0    => 'كيف يمكن إيجاد المواضيع و المشاركات كلها الخاصة بي في المنتدى؟',
         1    => 'يمكنك ذلك بالضغط على خيار البحث عن مشاركات العضو من خلال لوحة التحكم الخاص بك أو من خلال صفحة عرض معلومات العضو . للبحث عن مواضيعك استخدم خيار صفحة البحث المتقدم وستجد الخيارات الخاصة بذلك ',
     ),
     array(
@@ -300,15 +300,15 @@ $help = array(
         1    => 'قائمة الاشتراكات و المواضيع المفضلة',
     ),
     array(
-        0    => 'ما هو الفرق بين قائمة الاشتراكات و المواضيع المفضلة ؟',
+        0    => 'ما هو الفرق بين قائمة الاشتراكات و المواضيع المفضلة؟',
         1    => 'المواضيع المفضلة في phpBB3 تشبه خيار الإضافة للمفضلة في المتصفح حيث لن تُعلَم بأية تحديثات على الموضوع . لكن يمكنك زيارة الموضوع لمعرفة آخر التحديثات عن طريق قائمة المواضيع المفضلة . لكن قائمة الاشتراكات ستُعلم بأي تحديث عن المواضيع المشترك بها بالطريقة التي تفضلها ',
     ),
     array(
-        0    => 'كيف يمكنني الاشتراك في موضوع أو ساحة معينة ؟',
+        0    => 'كيف يمكنني الاشتراك في موضوع أو ساحة معينة؟',
         1    => 'للاشتراك لمتابعة ساحة معينة، عندما تدخل الساحة ستجد وصلة متابعة الساحة كذلك المواضيع يمكنك الاشتراك بها عندما ترد على الموضوع أو بالضغط على وصلة متابعة الموضوع ',
     ),
     array(
-        0    => 'كيف يمكن إلغاء الاشتراك في موضوع أو ساحة معينة ؟',
+        0    => 'كيف يمكن إلغاء الاشتراك في موضوع أو ساحة معينة؟',
         1    => 'لإلغاء الاشتراك ، اذهب إلى لوحة التحكم الشخصية واتبع رابط إلغاء الاشتراك ',
     ),
     array(
@@ -316,11 +316,11 @@ $help = array(
         1    => 'المرفقات',
     ),
     array(
-        0    => 'ما هي أنواع المرفقات الممسوحة في هذا المنتدى ؟',
+        0    => 'ما هي أنواع المرفقات الممسوحة في هذا المنتدى؟',
         1    => 'كل مدير منتدى يمكنه السماح أو عدم السماح لأنواع معينة من المرفقات . إذا لم تكن متأكدا من أنواع المرفقات الممسوحة، اتصل بمدير الموقع ',
     ),
     array(
-        0    => 'كيف يمكنني إيجاد المرفقات كلها الخاصة بي ؟',
+        0    => 'كيف يمكنني إيجاد المرفقات كلها الخاصة بي؟',
         1    => 'لإيجاد المرفقات الخاصة بك كلها اذهب إلى لوحة التحكم الشخصية واتبع الوصلة الخاصة بالمرفقات الموجودة بها ',
     ),
     array(
@@ -328,19 +328,19 @@ $help = array(
         1    => 'مشاكل phpBB3',
     ),
     array(
-        0    => 'من برمج هذا المنتدى ؟',
-        1    => 'هذا البرنامج (في صيغته غير المعدلة) تنتج, وتنشر وحقوقها phpBB Group. وهي متوفرة تحت ترخيص GNU General Public Licence ويمكن توزيعها مجاناً, انظر إلى الوصلة للمزيد من المعلومات ',
+        0    => 'من برمج هذا المنتدى؟',
+        1    => 'هذا البرنامج يتم كتابته وترخيصه بواسطة phpBB Group. إذا كنت تظن أن هناك ميزة يجب إضافتها، أو تريد التبليغ عن خطأ ما، يرجى زيارة موقع phpBB <a href="http://area51.phpbb.com/">Area51</a> حيث ستجد الأدوات لعمل ذلك.',
     ),
     array(
-        0    => 'من ترجم هذا المنتدى وأين احصل على الدعم بالعربية ؟',
+        0    => 'من ترجم هذا المنتدى وأين احصل على الدعم بالعربية؟',
         1    => 'ترجم المنتدى فريق الترجمة في <a href="http://www.phpbbarabia.com/" title="منتدى مجاني">phpBBArabia</a> ويمكن الحصول على الدعم من خلال زيارة <a href="http://www.phpbbarabia.com/community/" title="دعم phpBB">منتدى دعم phpBB</a> .',
     ),    
     array(
-        0    => 'لماذا لا أجد ميزة معينة أريدها ؟',
+        0    => 'لماذا لا أجد ميزة معينة أريدها؟',
         1    => 'بُرمِج هذا السكربت وهو مرخص لمجموعة phpBB. إن كنت ترى من المناسب إضافة ميزة جديدة للبرنامج عليك زيارة موقع المجموعة في phpbb.com وانظر ما رأي مجموعة phpBB. الرجاء عدم نشر طلبات جديدة على موقع phpbb.com, المجموعة تستعمل سورس فورج لقرار المميزات الجديدة. الرجاء قراءة النماذج, ورؤية موقفنا من تلك الميزة واتبع النصائح الخاصة بها',
     ),
     array(
-        0    => 'من اتصل به بخصوص مواضيع أو ردود غير قانونية أو غير لائقة ؟',
+        0    => 'من اتصل به بخصوص مواضيع أو ردود غير قانونية أو غير لائقة؟',
         1    => 'عليك مراسلة مدير المنتدى. إن لم تعرف من يكون عليك التخاطب مع مشرف المنتدى واسأله عن مسؤول المنتدى. إن لم تحصل على رد فخاطب صاحب الموقع (تستطيع ذلك من خلال whois ) أو إذا كان المنتدى في موقع مجاني (مثل yahoo, free.fr, f2s.com, وغيرها), فخاطب إدارة الموقع أو إدارة سوء الاستغلال. عليك ملاحظة أن phpBB Group ليس لها أي تحكم ولا تتحمل أي مسؤولية عن كيفية أو مكان أو من الشخص الذي يستعمل هذا المنتدى. ليس هناك أي فائدة من مخاطبة phpBB Group لأي مواضيع قانونية (القبض والتحري, المسؤولية القانونية, التعليقات والسب العلني, وغيرها) لها علاقة مباشرة بموقع phpbb.com أو برنامج phpBB بذاته. إن أرسلت رسالة الكترونية لـ phpBB Group عن أي شخص ثالث يستعمل البرنامج فربما لن تستلم ردا',
     ),
 );
