@@ -126,7 +126,8 @@ $lang = array_merge($lang, array(
 	'CREATE_FOLDER'	=> 'أضف مجلد …',
 	'CURRENT_IMAGE'	=> 'الصورة الحالية',
 	'CURRENT_PASSWORD'	=> 'كلمة المرور الحالية',
-	'CURRENT_PASSWORD_EXPLAIN'	=> 'عليك كتابة كلمة المرور الحالية في حال الرغبة بتغييرها أو تغيير البريد أو اسم المستخدم',
+	'CURRENT_PASSWORD_EXPLAIN'	=> 'يجب عليك إدخال كلمة مرورك إذا أردت تغيير بريدك أو اسم المستخدم.',
+	'CURRENT_CHANGE_PASSWORD_EXPLAIN' => 'لتغيير كلمة مرورك، بريدك، أو اسم المستخدم، يجب عليك إدخال كلمة مرورك الحالية.',
 	'CUR_PASSWORD_EMPTY'      => 'لم تقم بإدخال كلمة مرورك الحالية.',
 	'CUR_PASSWORD_ERROR'	=> 'كلمة المرور الحالية التي أدخلتها خاطئة',
 	'CUSTOM_DATEFORMAT'	=> 'مخصص',
@@ -361,6 +362,7 @@ $lang = array_merge($lang, array(
 	'RULE_ADDED'	=> 'أُضيف الشرط بنجاح',
 	'RULE_ALREADY_DEFINED'	=> 'هذا الشرط معرف سابقاً',
 	'RULE_DELETED'	=> 'أزيل الشرط بنجاح',
+	'RULE_LIMIT_REACHED'				=> 'لا يمكنك إضافة شروط جديدة. لقد وصلت إلى الحد الأقصى من عدد الشروط.',
 	'RULE_NOT_DEFINED'	=> 'لم يُعرّف الشرط بالصورة الصحيحة',
 	'RULE_REMOVED_MESSAGE'	=> 'حذِفت رسالة خاصة واحدة بواسطة مرشح الرسائل الخاصة',
 	'RULE_REMOVED_MESSAGES'	=> '%d رسائل خاصة تم حذفها بواسطة مرشح الرسائل الخاصة',
